SystemOrganization addCategory: #FuelProgressUpdate!
SystemOrganization addCategory: #'FuelProgressUpdate-Tests'!

Trait named: #FLTDefaultProgressHandler
	uses: {}
	category: 'FuelProgressUpdate'!

!FLTDefaultProgressHandler classSide methodsFor: 'instance creation' stamp: 'MartinDias 9/13/2011 19:41'!
newInstanceDo: aBlock

	| result |
	self title 
		displayProgressAt: Sensor cursorPoint 
		from: 0 
		to: 100 
		during: [ :aBlockToValueWithProgressUpdates | 
			result := aBlock value: (self newUpdatingProgressTo: aBlockToValueWithProgressUpdates) ].
	^result! !

!FLTDefaultProgressHandler classSide methodsFor: 'instance creation' stamp: 'MartinDias 9/13/2011 20:09'!
newUpdatingProgressTo: aBlock

	^self basicNew
		initializeWith: (self wrappedFilteringTooCloseEvaluations: aBlock atMostEvery: 250);
		yourself.! !

!FLTDefaultProgressHandler classSide methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 16:13'!
title

	self explicitRequirement ! !

!FLTDefaultProgressHandler classSide methodsFor: 'private' stamp: 'MartinDias 9/13/2011 20:08'!
wrappedFilteringTooCloseEvaluations: aBlockToValueWithProgressUpdates atMostEvery: milliseconds
	"Wraps the argument with another one that filters too-close evaluations. First and last evaluations (at 0 and at 100) are guaranteed."
	
	| lastEvaluationMilliseconds | 
	lastEvaluationMilliseconds := 0.
	^ [ :progress | 
		(progress = 100 or: [ (Time millisecondsSince: lastEvaluationMilliseconds) >= milliseconds ])
			ifTrue: [
				aBlockToValueWithProgressUpdates value: progress.
				lastEvaluationMilliseconds := Time millisecondClockValue ] ]! !

!FLTDefaultProgressHandler methodsFor: 'initialize-release' stamp: 'MartinDias 9/13/2011 18:41'!
initializeWith: aBlock

	self initialize.
	self progressBlock: aBlock.! !

!FLTDefaultProgressHandler methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 18:41'!
progressBlock: aBlock

	self explicitRequirement ! !

Trait named: #FLTProgressHandlerMock
	uses: {}
	category: 'FuelProgressUpdate-Tests'!

!FLTProgressHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 17:55'!
increaseTally

	self tally: self tally + 1! !

!FLTProgressHandlerMock methodsFor: 'initialize-release' stamp: 'MartinDias 9/13/2011 17:55'!
initialize

	super initialize.
	self tally: 0.! !

!FLTProgressHandlerMock methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 17:55'!
tally
	self explicitRequirement ! !

!FLTProgressHandlerMock methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 17:55'!
tally: anObject
	self explicitRequirement ! !

TestCase subclass: #FLBasicProgressTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

!FLBasicProgressTest methodsFor: 'hooks' stamp: 'MarianoMartinezPeck 12/9/2011 21:01'!
fuelAccept: aVisitor  
	^ aVisitor visitSubstitution: self! !

!FLBasicProgressTest methodsFor: 'hooks' stamp: 'MarianoMartinezPeck 12/9/2011 21:02'!
fuelSubstitution 
	^ nil! !

FLBasicProgressTest subclass: #FLDefaultProgressTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

!FLDefaultProgressTest methodsFor: 'running' stamp: 'MartinDias 9/13/2011 19:03'!
serializeAndMaterialize: anObject

	| aStream |
	aStream := (RWBinaryOrTextStream on: '') binary.

	FLSerializer newDefault 
		showProgress;
		serialize: anObject on: aStream.

	FLMaterializer newDefault
		showProgress;
		materializeFrom: aStream reset.! !

!FLDefaultProgressTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 20:50'!
testBasic

	self serializeAndMaterialize: (1 to: 1<<20)! !

FLBasicProgressTest subclass: #FLProgressAnalysisTest
	instanceVariableNames: 'progressHandlerMock analysis'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

!FLProgressAnalysisTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 18:37'!
analyze: anObject

	progressHandlerMock := FLProgressAnalysisHandlerMock new.
	
	analysis := 
		(FLProgressAnalysis
			newWith: (FLAnalyzer newDefault firstInMapperChain) root: anObject)
			progressHandler: progressHandlerMock; 
			run;
			yourself.! !

!FLProgressAnalysisTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 18:24'!
assertProgressUpdatesOf: anObject 

	self analyze: anObject.

	self
		assert: self minimumNumberOfProgressUpdates <= progressHandlerMock tally
		description: 'There is a minimum of progress updates that should happen'.
"	self
		deny: progressRecorder progressUpdates hasAnyDuplicate
		description: 'The bar should not update more than once to the same progress value'.
	self 
		assert: progressRecorder progressUpdates isSorted 
		description: 'The bar should always increment its progress'."
"	self 
		assert: 0 = progressRecorder progressUpdates first 
		description: 'The first update should be 0%'.
	self 
		assert: 100 = progressRecorder progressUpdates last 
		description: 'The last update should be 100%'"! !

!FLProgressAnalysisTest methodsFor: 'running' stamp: 'MartinDias 9/13/2011 18:24'!
minimumNumberOfProgressUpdates
	
	^analysis clusterization clusters size! !

!FLProgressAnalysisTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 18:18'!
testMedium
	self
		assertProgressUpdatesOf:
			(Array
				with: 1 @ 2.0 
				with: (3 / 4) @ (SmallInteger maxVal + 1)
				with: $X
				with: 'X'
				with: #(X)
				with: Set new)! !

!FLProgressAnalysisTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 18:18'!
testTiny

	self assertProgressUpdatesOf: $A! !

FLBasicProgressTest subclass: #FLProgressMaterializationTest
	instanceVariableNames: 'serialization materialization progressHandlerMock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

!FLProgressMaterializationTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 17:57'!
assertProgressUpdatesOf: anObject 

	self serializeAndMaterialize: anObject.

	self
		assert: self minimumNumberOfProgressUpdates <= progressHandlerMock tally
		description: 'There is a minimum of progress updates that should happen'.
"	self
		deny: progressRecorder progressUpdates hasAnyDuplicate
		description: 'The bar should not update more than once to the same progress value'.
	self 
		assert: progressRecorder progressUpdates isSorted 
		description: 'The bar should always increment its progress'."
"	self 
		assert: 0 = progressRecorder progressUpdates first 
		description: 'The first update should be 0%'.
	self 
		assert: 100 = progressRecorder progressUpdates last 
		description: 'The last update should be 100%'"! !

!FLProgressMaterializationTest methodsFor: 'running' stamp: 'MartinDias 9/13/2011 16:33'!
minimumNumberOfProgressUpdates
	"The progress bar should advance at least when cluster materializes."
	
	^serialization clusters size! !

!FLProgressMaterializationTest methodsFor: 'tests' stamp: 'MartinDias 1/5/2012 14:36'!
serializeAndMaterialize: anObject

	| aStream |
	aStream := (RWBinaryOrTextStream on: '') binary.

	progressHandlerMock := FLProgressMaterializationHandlerMock new.
	
	serialization := 
		(FLProgressSerialization
			with: (FLEncoder on: aStream) 
			root: anObject 
			analyzer: FLAnalyzer newDefault)
			progressHandler: FLProgressSerializationHandlerMock new;
			run;
			yourself.

	materialization := 
		(FLProgressMaterialization 
			with: (FLDecoder on: aStream reset migrations: #()))
			progressHandler: progressHandlerMock;
			run;
			yourself.! !

!FLProgressMaterializationTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 17:40'!
testMedium
	self
		assertProgressUpdatesOf:
			(Array
				with: 1 @ 2.0 
				with: (3 / 4) @ (SmallInteger maxVal + 1)
				with: $X
				with: 'X'
				with: #(X)
				with: Set new)! !

!FLProgressMaterializationTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 17:40'!
testTiny

	self assertProgressUpdatesOf: $A! !

FLBasicProgressTest subclass: #FLProgressSerializationTest
	instanceVariableNames: 'serialization progressHandlerMock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

!FLProgressSerializationTest classSide methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 10/31/2011 11:59'!
packageNamesUnderTest
	^ #('FuelProgressUpdate')! !

!FLProgressSerializationTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 18:00'!
assertProgressUpdatesOf: anObject 

	self serialize: anObject.

	self
		assert: self minimumNumberOfProgressUpdates <= progressHandlerMock tally
		description: 'There is a minimum of progress updates that should happen'.
"	self
		deny: progressRecorder progressUpdates hasAnyDuplicate
		description: 'The bar should not update more than once to the same progress value'.
	self 
		assert: progressRecorder progressUpdates isSorted 
		description: 'The bar should always increment its progress'."
"	self 
		assert: 0 = progressRecorder progressUpdates first 
		description: 'The first update should be 0%'.
	self 
		assert: 100 = progressRecorder progressUpdates last 
		description: 'The last update should be 100%'"! !

!FLProgressSerializationTest methodsFor: 'running' stamp: 'MartinDias 9/13/2011 17:42'!
minimumNumberOfProgressUpdates
	"The progress bar should advance at least when cluster materializes."
	
	^serialization clusters size! !

!FLProgressSerializationTest methodsFor: 'tests' stamp: 'MartinDias 1/6/2012 22:55'!
newStream

	^ (RWBinaryOrTextStream on: '') binary! !

!FLProgressSerializationTest methodsFor: 'tests' stamp: 'MartinDias 1/5/2012 14:36'!
serialize: anObject

	| aStream |
	aStream := self newStream.

	progressHandlerMock := FLProgressSerializationHandlerMock new.
	
	serialization := 
		(FLProgressSerialization
			with: (FLEncoder on: aStream)
			root: anObject
			analyzer: FLAnalyzer newDefault)
			progressHandler: progressHandlerMock; 
			run;
			yourself.
! !

!FLProgressSerializationTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 17:42'!
testMedium
	self
		assertProgressUpdatesOf:
			(Array
				with: 1 @ 2.0 
				with: (3 / 4) @ (SmallInteger maxVal + 1)
				with: $X
				with: 'X'
				with: #(X)
				with: Set new)! !

!FLProgressSerializationTest methodsFor: 'tests' stamp: 'MartinDias 9/13/2011 17:42'!
testTiny

	self assertProgressUpdatesOf: $A! !

FLSerialization subclass: #FLProgressSerialization
	instanceVariableNames: 'progressHandler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLProgressSerialization commentStamp: 'MartinDias 4/28/2011 15:30' prior: 0!
I am a serializer that inform progress during the serialization.

With the message #serialize:analyzer:analysisCheckpoints:, I introduce a new parameter to the serialization, called the *analysisCheckpoints*. It is a collection whose elements are the only objects that will produce progress increments during the dependency graph analysis, that is done in the first part of the serialization process. See the example below.

Now, an example of use, serializing 2^14 points. 

	| objectToSerialize analysisCheckpoints run |
	objectToSerialize := (1 to: 1 << 14) collect: [ :i | i @ (i+1) ].
	analysisCheckpoints := 1 to: 1 << 14.
	(FLProgressUpdaterSerializer example)
		serialize: objectToSerialize
		analyzer: FLProgressUpdaterSerializer defaultAnalyzer
		analysisCheckpoints: analysisCheckpoints.


Note: In the method #defaultProgressBarFactory is defined the default way of displaying progress. It is possible to change it using #progressBarFactory:.

!

!FLProgressSerialization classSide methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 17:37'!
defaultProgressBarFactory

	self flag: #todo. "this is horrible"
	^ [ :aBlockThatNotifiesToProgressHandler | 
		'Writing to stream' 
			displayProgressAt: Sensor cursorPoint 
			from: 0 
			to: 100 
			during: [ :aBlockToValueWithProgressUpdates | 
				aBlockThatNotifiesToProgressHandler value: 
					(FLDefaultProgressSerializationHandler 
						value: aBlockToValueWithProgressUpdates 
						atMostEvery: 250) ]]! !

!FLProgressSerialization methodsFor: 'serializing' stamp: 'MartinDias 8/29/2011 16:48'!
clusterInstancesStepOf: aCluster

	super clusterInstancesStepOf: aCluster.
	self progressHandler serializedCluster: aCluster.! !

!FLProgressSerialization methodsFor: 'serializing' stamp: 'MartinDias 12/29/2011 17:03'!
headerStep

	self progressHandler serializationBegin: clusters and: encoder objectCount.
	super headerStep.! !

!FLProgressSerialization methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 18:02'!
progressHandler
	^ progressHandler! !

!FLProgressSerialization methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 18:02'!
progressHandler: anObject
	progressHandler := anObject! !

!FLProgressSerialization methodsFor: 'serializing' stamp: 'MartinDias 9/13/2011 19:57'!
run

	super run.
	self progressHandler serializationEnd.
! !

FLAnalysis subclass: #FLProgressAnalysis
	instanceVariableNames: 'progressHandler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLProgressAnalysis commentStamp: 'MartinDias 4/28/2011 15:32' prior: 0!
I am an analyzer that inform progress during the dependency graph iteration, in the first part of the serialization process.
!

!FLProgressAnalysis methodsFor: 'analyze' stamp: 'MartinDias 5/31/2011 18:44'!
mapAndTrace: anObject

	progressHandler analyzedObject: anObject. 
	super mapAndTrace: anObject.! !

!FLProgressAnalysis methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 18:22'!
progressHandler
	^ progressHandler! !

!FLProgressAnalysis methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 18:22'!
progressHandler: anObject
	progressHandler := anObject! !

!FLProgressAnalysis methodsFor: 'analyze' stamp: 'MarianoMartinezPeck 10/24/2011 11:01'!
run

	progressHandler analysisBegin: (IdentitySet with: root).
	super run! !

!FLAnalyzer methodsFor: '*FuelProgressUpdate-protected' stamp: 'MartinDias 9/14/2011 00:16'!
setProgressAnalysis

	analysisFactory := [:anObject | 
		FLDefaultProgressAnalysisHandler newInstanceDo: [:aHandler |
			(FLProgressAnalysis 
				newWith: self firstInMapperChain 
				root: anObject)
				progressHandler: aHandler;
				run;
				yourself ] ]! !

!FLAnalyzer methodsFor: '*FuelProgressUpdate-configuring' stamp: 'MartinDias 9/13/2011 19:22'!
showProgress

	self setProgressAnalysis! !

!OrderedCollection methodsFor: '*FuelProgressUpdate' stamp: 'MartinDias 10/12/2010 16:11'!
hasAnyDuplicate
	"Answers if there is an element added more than one time"

	^ self size ~= self asSet size ! !

!FLMaterializer methodsFor: '*FuelProgressUpdate-protected' stamp: 'MartinDias 1/6/2012 20:34'!
setProgressMaterialization

	materializationFactory := [:aDecoder | 
		FLDefaultProgressMaterializationHandler newInstanceDo: [:aHandler |
			(FLProgressMaterialization 
				with: aDecoder)
				progressHandler: aHandler;
				run;
				yourself ] ]! !

!FLMaterializer methodsFor: '*FuelProgressUpdate-configuring' stamp: 'MartinDias 9/13/2011 19:18'!
showProgress

	self setProgressMaterialization
	
	
! !

FLMaterialization subclass: #FLProgressMaterialization
	instanceVariableNames: 'progressHandler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLProgressMaterialization commentStamp: 'MartinDias 4/28/2011 16:53' prior: 0!
I am a materializer that inform progress during the materialization process.

Now, an example of use, serializing and materializing 2^14 rectangles. 

	| serializer objectToSerialize |
	objectToSerialize := (1 to: 1 << 14) collect: [ :i | i @ (i+1) corner: (i+2) @ (i+3) ].
	serializer := FLSerializer example.
	serializer serialize: objectToSerialize.
	(FLProgressUpdaterMaterializer on: serializer stream reset) materialize.


Note: In the method #defaultProgressBarFactory is defined the default way of displaying progress. It is possible to change it using #progressBarFactory:.

!

!FLProgressMaterialization methodsFor: 'private' stamp: 'MartinDias 9/12/2011 02:55'!
clusterInstancesStep

	super clusterInstancesStep.
	self progressHandler materializedCluster.! !

!FLProgressMaterialization methodsFor: 'private' stamp: 'MartinDias 12/29/2011 19:00'!
headerStep

	super headerStep.
	self progressHandler materializationBegin: self objects capacity.! !

!FLProgressMaterialization methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:04'!
progressHandler
	^ progressHandler! !

!FLProgressMaterialization methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 16:04'!
progressHandler: anObject
	progressHandler := anObject! !

!FLProgressMaterialization methodsFor: 'accessing' stamp: 'MartinDias 8/29/2011 16:26'!
registerAll: aCollection
	
	super registerAll: aCollection.
	self progressHandler materializedObjects: aCollection.! !

!FLProgressMaterialization methodsFor: 'materializing' stamp: 'MartinDias 9/12/2011 03:02'!
run

	super run.
	self progressHandler materializationEnd.! !

Object subclass: #FLProgressAnalysisHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

FLProgressAnalysisHandler subclass: #FLDefaultProgressAnalysisHandler
	uses: FLTDefaultProgressHandler
	instanceVariableNames: 'progressBlock analysisCheckpoints remainingAnalysisCheckpoints'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

FLDefaultProgressAnalysisHandler class
	uses: FLTDefaultProgressHandler classTrait
	instanceVariableNames: ''!

!FLDefaultProgressAnalysisHandler classSide methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 19:42'!
title
	^'Analyzing graph'! !

!FLDefaultProgressAnalysisHandler methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 15:47'!
analysisBegin: aCollection

	analysisCheckpoints := aCollection.
	remainingAnalysisCheckpoints := IdentitySet newFrom: aCollection.
	progressBlock value: 0! !

!FLDefaultProgressAnalysisHandler methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 15:47'!
analyzedObject: anObject 

	remainingAnalysisCheckpoints
		remove: anObject
		ifAbsent: [ ^self ].
	progressBlock value: self progressAnalyzing.! !

!FLDefaultProgressAnalysisHandler methodsFor: 'private' stamp: 'MartinDias 9/13/2011 19:59'!
progressAnalyzing

	^ 100 * (1 - ((remainingAnalysisCheckpoints size + 1) / (analysisCheckpoints size + 1)))! !

!FLDefaultProgressAnalysisHandler methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 20:46'!
progressBlock: aBlock

	progressBlock := aBlock! !

!FLProgressAnalysisHandler methodsFor: 'progress handling' stamp: 'MartinDias 9/12/2011 00:02'!
analysisBegin: aCollection

	self subclassResponsibility ! !

!FLProgressAnalysisHandler methodsFor: 'progress handling' stamp: 'MartinDias 9/12/2011 00:02'!
analyzedObject: anObject 

	self subclassResponsibility ! !

FLProgressAnalysisHandler subclass: #FLProgressAnalysisHandlerMock
	uses: FLTProgressHandlerMock
	instanceVariableNames: 'tally'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

FLProgressAnalysisHandlerMock class
	uses: FLTProgressHandlerMock classTrait
	instanceVariableNames: ''!

!FLProgressAnalysisHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 18:27'!
analysisBegin: aCollection

	self increaseTally! !

!FLProgressAnalysisHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 18:26'!
analyzedObject: anObject

	self increaseTally! !

!FLProgressAnalysisHandlerMock methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 18:26'!
tally
	^tally! !

!FLProgressAnalysisHandlerMock methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 18:26'!
tally: anObject
	tally := anObject! !

Object subclass: #FLProgressMaterializationHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

FLProgressMaterializationHandler subclass: #FLDefaultProgressMaterializationHandler
	uses: FLTDefaultProgressHandler
	instanceVariableNames: 'materializingEstimatedPercentage progressBlock numberOfObjectsAlreadyMaterialized numberOfObjectsToMaterialize'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLDefaultProgressMaterializationHandler commentStamp: 'MartinDias 4/28/2011 16:47' prior: 0!
My job is to estimate a percentage of completeness of a materialization run. I am a collaborator of FLProgressUpdaterMaterializer.!

FLDefaultProgressMaterializationHandler class
	uses: FLTDefaultProgressHandler classTrait
	instanceVariableNames: ''!

!FLDefaultProgressMaterializationHandler classSide methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 16:15'!
title
	^'Reading from stream'! !

!FLDefaultProgressMaterializationHandler methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 16:07'!
initializeWith: aBlock

	self initialize.
	progressBlock := aBlock.
	materializingEstimatedPercentage := 90.! !

!FLDefaultProgressMaterializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:40'!
materializationBegin: objectCount

	numberOfObjectsAlreadyMaterialized := 0.
	numberOfObjectsToMaterialize := objectCount.
	progressBlock value: 0! !

!FLDefaultProgressMaterializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:41'!
materializationEnd
	
	progressBlock value: 100! !

!FLDefaultProgressMaterializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:40'!
materializedCluster
	
	progressBlock value: self progressMaterializing! !

!FLDefaultProgressMaterializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 16:41'!
materializedObjects: aCollection 

	numberOfObjectsAlreadyMaterialized := numberOfObjectsAlreadyMaterialized + aCollection size! !

!FLDefaultProgressMaterializationHandler methodsFor: 'private' stamp: 'MartinDias 4/28/2011 16:28'!
progressMaterializing

	^ materializingEstimatedPercentage * numberOfObjectsAlreadyMaterialized / numberOfObjectsToMaterialize! !

!FLProgressMaterializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 9/11/2011 23:58'!
materializationBegin: objectCount

	self subclassResponsibility ! !

!FLProgressMaterializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 9/11/2011 23:58'!
materializationEnd
	
	self subclassResponsibility ! !

!FLProgressMaterializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 9/11/2011 23:59'!
materializedCluster
	
	self subclassResponsibility ! !

!FLProgressMaterializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 9/11/2011 23:59'!
materializedObjects: aCollection 

	self subclassResponsibility ! !

FLProgressMaterializationHandler subclass: #FLProgressMaterializationHandlerMock
	uses: FLTProgressHandlerMock
	instanceVariableNames: 'tally'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

FLProgressMaterializationHandlerMock class
	uses: FLTProgressHandlerMock classTrait
	instanceVariableNames: ''!

!FLProgressMaterializationHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 17:12'!
materializationBegin: objectCount

	self increaseTally! !

!FLProgressMaterializationHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 17:12'!
materializationEnd

	self increaseTally! !

!FLProgressMaterializationHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 17:12'!
materializedCluster

	self increaseTally! !

!FLProgressMaterializationHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 17:12'!
materializedObjects: aCollection

	self increaseTally! !

!FLProgressMaterializationHandlerMock methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 17:12'!
tally
	^ tally! !

!FLProgressMaterializationHandlerMock methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 17:54'!
tally: anObject
	tally := anObject! !

Object subclass: #FLProgressSerializationHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLProgressSerializationHandler commentStamp: 'MartinDias 4/29/2011 07:03' prior: 0!
My job is to estimate a percentage of completeness of a serialization run. I am a collaborator of FLProgressUpdaterSerializer.!

FLProgressSerializationHandler subclass: #FLDefaultProgressSerializationHandler
	uses: FLTDefaultProgressHandler
	instanceVariableNames: 'progressBlock numberOfObjectsToSerialize numberOfObjectsAlreadySerialized'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate'!

!FLDefaultProgressSerializationHandler commentStamp: 'MartinDias 4/28/2011 16:47' prior: 0!
My job is to estimate a percentage of completeness of a serialization run. I am a collaborator of FLProgressUpdaterSerializer.!

FLDefaultProgressSerializationHandler class
	uses: FLTDefaultProgressHandler classTrait
	instanceVariableNames: ''!

!FLDefaultProgressSerializationHandler classSide methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 19:39'!
title
	^'Writing to stream'! !

!FLDefaultProgressSerializationHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
progressBlock
	^ progressBlock! !

!FLDefaultProgressSerializationHandler methodsFor: 'accessing' stamp: 'MartinDias 4/28/2011 12:18'!
progressBlock: anObject
	progressBlock := anObject! !

!FLDefaultProgressSerializationHandler methodsFor: 'private' stamp: 'MartinDias 9/13/2011 20:49'!
progressSerializing

	^ 100 * numberOfObjectsAlreadySerialized / numberOfObjectsToSerialize! !

!FLDefaultProgressSerializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 11:41'!
serializationBegin: clusteredObjects and: objectCount

	numberOfObjectsToSerialize := objectCount.
	numberOfObjectsAlreadySerialized := 0.
	progressBlock value: self progressSerializing.! !

!FLDefaultProgressSerializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/28/2011 11:25'!
serializationEnd

	progressBlock value: 100.! !

!FLDefaultProgressSerializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 8/21/2011 09:36'!
serializedCluster: aCluster

	numberOfObjectsAlreadySerialized := numberOfObjectsAlreadySerialized + aCluster objects size.
	progressBlock value: self progressSerializing.! !

!FLProgressSerializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:34'!
serializationBegin: clusteredObjects and: objectCount

	self subclassResponsibility ! !

!FLProgressSerializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 4/29/2011 06:34'!
serializationEnd

	self subclassResponsibility ! !

!FLProgressSerializationHandler methodsFor: 'progress handling' stamp: 'MartinDias 8/21/2011 09:36'!
serializedCluster: aCluster

	self subclassResponsibility ! !

FLProgressSerializationHandler subclass: #FLProgressSerializationHandlerMock
	uses: FLTProgressHandlerMock
	instanceVariableNames: 'tally'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'FuelProgressUpdate-Tests'!

FLProgressSerializationHandlerMock class
	uses: FLTProgressHandlerMock classTrait
	instanceVariableNames: ''!

!FLProgressSerializationHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 17:58'!
serializationBegin: clusteredObjects and: objectCount

	self increaseTally ! !

!FLProgressSerializationHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 17:58'!
serializationEnd

	self increaseTally ! !

!FLProgressSerializationHandlerMock methodsFor: 'progress handling' stamp: 'MartinDias 9/13/2011 17:58'!
serializedCluster: aCluster

	self increaseTally ! !

!FLProgressSerializationHandlerMock methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 17:58'!
tally
	^tally! !

!FLProgressSerializationHandlerMock methodsFor: 'accessing' stamp: 'MartinDias 9/13/2011 17:58'!
tally: anObject
	tally := anObject! !

!FLSerializer methodsFor: '*FuelProgressUpdate-protected' stamp: 'MartinDias 1/6/2012 20:33'!
setProgressSerialization

	serializationFactory := [:anObject :anEncoder | 
		FLDefaultProgressSerializationHandler newInstanceDo: [:aHandler |
			(FLProgressSerialization 
				with: anEncoder
				root: anObject 
				analyzer: self analyzer showProgress)
				progressHandler: aHandler;
				run;
				yourself ] ]! !

!FLSerializer methodsFor: '*FuelProgressUpdate-configuring' stamp: 'MartinDias 1/6/2012 20:32'!
showProgress

	self setProgressSerialization! !
